import argparse

from max7219simple import Strip, version

if __name__ == "__main__":
    parser = argparse.ArgumentParser(description="Max7219 - A controller for MAX7219-driver led matrices")
    parser.add_argument("--version", action="version", version="%(prog)s " + version)
    parser.add_argument("--spidev", "-d",
                        default="/dev/spidev0.0",
                        help="Spidev device to use (default to /dev/spidev0.0)")
    parser.add_argument("--size", "-s",
                        default=1,
                        type=int,
                        help="Size of the strip")
    parser.add_argument("--clear", "-c",
                        action="store_true",
                        default=False,
                        help="Clear the display")
    parser.add_argument("--fill",
                        action="store_true",
                        default=False,
                        help="Fill the display")
    parser.add_argument("--brightness", "-b",
                        default=-1,
                        type=int,
                        help="Brightness (between 0 and 15)")
    parser.add_argument("--scroll",
                        action="store_true",
                        default=False,
                        help="Scroll the message")
    parser.add_argument("--rotate", "-r",
                        action="store_true",
                        default=False,
                        help="Rotate the display")
    parser.add_argument("--message", "-m",
                        default="",
                        help="Message to be displayed")
    args = parser.parse_args()

    if args.spidev.startswith("/dev/spidev"):
        bus, device = args.spidev[11:].split(".")

    strip = Strip(args.size, spi_bus=int(bus), spi_device=int(device), rotate=args.rotate)

    if args.brightness >= 0:
        strip.brightness(args.brightness)

    if args.clear:
        strip.clear()
        strip.commit()

    if args.fill:
        strip.fill()
        strip.commit()

    if len(args.message) > 0:
        if args.scroll:
            try:
                strip.scroll(args.message)
            except KeyboardInterrupt:
                strip.clear()
                strip.commit()
        else:
            strip.message(args.message)
        strip.commit()
